#
# spec file for package FAudio
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           FAudio
Version:        24.05
Release:        1.1
Summary:        A reimplementation of the XNA Game Studio libraries
License:        Zlib
Group:          Development/Libraries/C and C++
URL:            https://fna-xna.github.io
Source0:        https://github.com/FNA-XNA/FAudio/archive/%{version}/%{name}-%{version}.tar.gz
Source1:        baselibs.conf
Patch0:         faudio-older-sdl2.patch
BuildRequires:  cmake
BuildRequires:  gcc-c++
BuildRequires:  pkgconfig
BuildRequires:  unzip
BuildRequires:  cmake(sdl2)

%description
FNA is a reimplementation of the Microsoft XNA Game Studio 4.0 Refresh libraries.

%package -n libFAudio0
Summary:        A reimplementation of the XNA Game Studio libraries
Group:          System/Libraries

%description -n libFAudio0
FNA is a reimplementation of the Microsoft XNA Game Studio 4.0 Refresh libraries.

%package devel
Summary:        FAudio Development Libraries
Group:          Development/Languages/C and C++
Requires:       libFAudio0 = %{version}

%description devel
FNA is a reimplementation of the Microsoft XNA Game Studio 4.0 Refresh libraries.

%prep
%setup -q
%if 0%{?suse_version} < 1550
%autopatch -p1
%endif

%build
%cmake \
  -DCMAKE_BUILD_TYPE=Release
%cmake_build

%install
%cmake_install

%post -n libFAudio0 -p /sbin/ldconfig
%postun -n libFAudio0 -p /sbin/ldconfig

%files -n libFAudio0
%license LICENSE
%{_libdir}/libFAudio.so.0*

%files devel
%license LICENSE
%{_includedir}/FAudio.h
%{_includedir}/FAPOFX.h
%{_includedir}/FACT3D.h
%{_includedir}/F3DAudio.h
%{_includedir}/FACT.h
%{_includedir}/FAPO.h
%{_includedir}/FAudioFX.h
%{_includedir}/FAPOBase.h
%{_libdir}/libFAudio.so
%dir %{_libdir}/cmake
%dir %{_libdir}/cmake/FAudio
%{_libdir}/cmake/FAudio/FAudio-targets.cmake
%{_libdir}/cmake/FAudio/FAudioConfig.cmake
%{_libdir}/cmake/FAudio/FAudio-targets-release.cmake
%{_libdir}/pkgconfig/FAudio.pc

%changelog
* Fri May 17 2024 Dirk Müller <dmueller@suse.com>
-update to 24.05:
  * New Features:
  * Initial work to support SDL 3.0
  * FACT: Fix a crash for XACT Cues which may have variation set
    with no variation data
* Mon Apr  8 2024 Dirk Müller <dmueller@suse.com>
- update to 24.04:
  * pkgconfig files now explicitly include the SDL2 dependency
* Mon Mar 18 2024 ming li <mli@suse.com>
- Update to 24.03:
  * New Features:
    Update to FNA3D 24.03
    Update to FAudio 24.03
  * Fixes:
    DDSFromStreamEXT: Fixed some logic errors in the DDS header parser
    NativeAOT: Improve failure message when missing types in rd.xml
    Separated obj folder paths for NetFramework/NetStandard projects,
    fixes weird compiler conflicts
  update to 24.02:
  * New Features:
    Update to FNA3D 24.02
    Update to FAudio 24.02
  * Modified Features:
    DDSFromStreamEXT now supports RGBA DDS textures, in addition to BGRA
  * Fixes:
    SDL2_FNAPlatform:
    Display orientation events are now ignored on non-mobile platforms
    Worked around a display hotplugging timing issue in SDL
    Improved error reporting when FNA3D fails to decode images
  update to 24.01:
  * New Features:
    Update to FNA3D 24.01
    Update to FAudio 24.01
    Added support for detecting PlayStation gamepads hidden behind
    Steam Virtual Gamepads
    This feature requires SDL 2.30 or newer
  * Removed Features:
    UWP support has been removed, Xbox developers should migrate to GDK
  * Fixes:
    Removed the x64 Platform from modern C# project files, this attribute
    is now inherited from the Solution instead
    GraphicsDeviceManager now warns when calling ApplyChanges too early in
    the Game lifecycle
    Fixed FNADllMap support on iOS/tvOS
  update to 23.12.07:
  * Fixes:
    Update to FNA3D 23.12.07
    Fixed GraphicsResource finalization to use atomics, rather than managed
    queues
* Fri Dec  1 2023 Dirk Müller <dmueller@suse.com>
- update to 23.12:
  * Removed an unused variable from the QOA decoder. 23.12 is
    functionally identical to 23.11.
* Tue Nov 21 2023 Dirk Müller <dmueller@suse.com>
- update to 23.11:
  * The mixer thread no longer crashes when attempting to read
    voices using WMAUDIO3 buffer data
  * SDL2: Fix regression that prevented devices with >8 channels
    from opening
* Wed Oct 18 2023 Dirk Müller <dmueller@suse.com>
- update to 23.10:
  * Minor static analysis fix for F3DAudio
  * FACT now supports all publicly known WaveBank format versions
* Fri Jul 21 2023 Dirk Müller <dmueller@suse.com>
- update to 23.07:
  * FACT: When parsing SoundBanks, explicitly update the read
    offset for each data region
  * XNA_Song: Fix possible truncation of total seconds when
    opening QOA files
  * Xbox GDK support is now considered Ready to Ship
  * UWP support is now deprecated and will be removed in FAudio
    24.01
  * XNA_Song now supports QOA input files
  * FACT: Add support for `WAVEBANKSTREAMING_INVALIDCONTENT`
    notifications
  * Added FilterWetDryMixEXT extension
* Fri Mar 17 2023 Dirk Müller <dmueller@suse.com>
- update to 23.03:
  * CMake: Add feature macros for usleep for tests
  * GDK:
  - GDK now builds dynamic libraries, rather than static
  - Look for "SDL" rather than "SDL2", to match the
    upstream Git repository name
* Tue Jan  3 2023 Dirk Müller <dmueller@suse.com>
- update to 23.01:
  * Remove PlatformToolset lines from visualc-gdk project
* Sun Dec  4 2022 Dirk Müller <dmueller@suse.com>
- update to 22.12:
  * Added a Visual Studio solution for GDK support
  * Minor cleanup in the utils/ folder
* Mon Oct 24 2022 Aaron Stern <ukbeast89@protonmail.com>
- Update to 22.10:
  * Added a quick comment to the SDL backend.
* Mon Oct 24 2022 Aaron Stern <ukbeast89@protonmail.com>
- Update to 22.09.01:
  * Fix a regression where requesting a specific mastering voice format
    would return a format overwritten by device defaults
* Mon Oct 24 2022 Aaron Stern <ukbeast89@protonmail.com>
- Update to 22.09:
  * Update to SDL 2.24. This has been made a hard requirement, as it
    fixes/adds way too much to ignore:
    2.1 and 4.1 audio is now supported
  * On Windows, we now prioritize DirectSound over WASAPI
  * The PulseAudio samples hack has been removed
  * The non-power-of-two samples hack for Emscripten/OSS has also been removed
  * GetDeviceDetails(0) now uses SDL_GetDefaultAudioInfo, obsoleting our hack
* Tue Aug  9 2022 Aaron Stern <ukbeast89@protonmail.com>
- Update to 22.08:
  * FACT: Add support for WAVEBANKPREPARED notifications
  * Included the matrix coefficient test program in matrix_defaults.inl,
    for developers that need to replicate it
  * FXReverb: Fix a spec violation in Process() that could corrupt reverb output
    when enabled/disabled with precise timing
  * FACT: Fill all fields for WAVESTOP notifications, avoiding uninitialized memory issues
* Mon May  9 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.05. Changes since 22.02:
  * FACT: Clamp SoundBank Q factor to ignore the 0.67 case, for now
  * CMake: Remove some uicommon files that no longer exist
* Tue Feb 15 2022 Aaron Stern <ukbeast89@protonmail.com>
- update to 22.02:
  * The Wine/Win32 backend is now considered stable.
    All Wine users should upgrade to 7.0 or newer
    All non-Wine users will (and should) continue to use
    the SDL backend.
  * GStreamer support has been removed.
    Wine/Win32 will continue to use MediaFoundation.
    All other users should already be on patent/royalty-free
    codecs.
  * utils: Minor cleanup of uicommon.
  * csharp: Expose an IntPtr overload for
    stb_vorbis_get_samples_float_interleaved.
* Mon Jan 10 2022 Aaron Stern <ukbeast89@protonmail.com>
- update 22.01:
  * Continued work on the experimental Wine/Win32 platform backend.
* Thu Dec 30 2021 Aaron Stern <ukbeast89@protonmail.com>
- update to 21.12:
  * Fixed a build error when WMA support is enabled.
* Sun Nov 28 2021 Aaron Stern <ukbeast89@protonmail.com>
- update to 21.11:
  * GStreamer support is now deprecated.
    Wine users should migrate to 6.20 and newer, and everyone else should move to
    codecs that are not patent-encumbered.
    GStreamer support will be fully removed in the first release after Wine 7.0.
  * Removed the C++ wrapper. Use the headers/PE binaries found in Wine 6.20 and newer.
  * Minor fixes and cleanups found by Coverity
  * Dont assert on WMA buffer and FAUDIO_FORMAT_EXTENSIBLE type
  * FACT: Send FACTNOTIFICATIONTYPE_CUESTOP Notification on Cue Stop
  * Continued work on the experimental Wine/Win32 platform backend
* Sun Oct 17 2021 Aaron Stern <ukbeast89@protonmail.com>
- update to 21.10:
  * Minor WinRT project update for latest SDL Git revision
  * Continued work on the experimental Wine/Win32 platform backend
* Thu Sep 16 2021 Aaron Stern <ukbeast89@protonmail.com>
- update to 21.09:
  * FACT: Fix a crash from an uninitialized pointer when a WaveBank does not have a name
    table.
  * platform_sdl2: When querying the default device, ignore audio devices with way too many
    channels.
  * platform_win32: Minor Win32 buildfixes
* Tue Jul 13 2021 Aaron Stern <ukbeast89@protonmail.com>
- update to 21.07:
  * Fix incorrect value for MF_MT_AUDIO_AVG_BYTES_PER_SECOND.
* Tue May  4 2021 Aaron Stern <ukbeast89@protonmail.com>
- update to 21.05:
  * CMake: Add 'Requires' for GStreamer to the pkgconfig file
  * Updated source to github.
* Mon Apr  5 2021 Aaron Stern <ukbeast89@protonmail.com>
- update to 21.04:
  * Added support for SDL_GetAudioDeviceSpec, coming in a future SDL release
  * FACT: Implemented accurate Fast/Slow/SinCos RPC curve types
  * Added support for XMA2 audio, for Xbox 360 data
  * Voice filters/effects should be processed even when SendCount is 0
  * FACT: Fix parsing/calculation of filter Q factors
  * FACT: Enforce STOPPING flag for fade-outs or RPC releases
  * FACT: Various fixes for parsing big-endian SoundBanks
* Sat Mar 13 2021 Aaron Stern <ukbeast89@protonmail.com>
- update to 21.03.5:
  * Fixes a regression that caused SoundBanks to no longer parse correctly
* Tue Mar  2 2021 Aaron Stern <ukbeast89@protonmail.com>
- update to 21.03:
  * Implemented FACT_FLAG_MANAGEDATA
  * Implemented the CUEPLAY and CUESTOP notification types
  * Added support for XACT 3.0 content
  * Added support for WaveBanks with endian-swapped PCM data
* Sun Feb  7 2021 Matthias Eliasson <elimat@opensuse.org>
- update to 21.02:
  * XACT: All notification types with the PERSIST flag are now recorded
* Sun Jan  3 2021 Aaron Stern <ukbeast89@protonmail.com>
- update to 21.01:
  Enforce SDL 2.0.9 or newer as a build requirement
  Micro-optimize byte swapping for XACT file parsing
* Mon Dec 28 2020 Aaron Stern <ukbeast89@protonmail.com>
- update to 20.12:
  Added an x64 configuration to visualc
  CMake project now generates a pkgconfig file
  Fix compatibility with CMake 2.8.12
  GStreamer builds now explicitly check for >=1.9.2
  Initialize the subformat for GetDeviceFormat, fixes a ton of Ubisoft games
  Don't assert when FAudio_Initialize Flags includes FAUDIO_DEBUG_ENGINE
* Wed Oct  7 2020 Aaron Stern <ukbeast89@protonmail.com>
- update to 20.10:
  Add support for WAVESTOP notifications
  Add support for engines without settings files (or empty settings files)
  Add power-of-two quantum fallback paths for *BSD and Emscripten
  Return a unique error code for audio engines with a bad platform ID
  Fix a deadlock in Wolfenstein: The Old Blood related to callbacks
  Fix a crash for streaming WaveBanks when calling Destroy
  stb_vorbis: Handle malloc(0) calls
* Fri Sep 11 2020 Aaron Stern <ukbeast89@protonmail.com>
- The FFmpeg backend for WMA decoding has been replaced with GStreamer.
  Distributors are encouraged to configure their FAudio builds with
  - DGSTREAMER=ON even if a WMA plugin is not available by default;
  end users can provide their own plugins if needed.
  added -DGSTREAMER=ON flag for gstreamer backend.
* Fri Sep  4 2020 Dirk Mueller <dmueller@suse.com>
- update to 20.09:
  IGLDevice has been replaced with FNA3D, the new graphics library for FNA!
  Direct3D 11 is now supported and is the default for Windows/Xbox
  Vulkan is now available as an experimental backend
  Metal is now the default for Apple platforms
  ModernGL and ThreadedGL have been removed
  THREADED_GL and DISABLE_THREADING have been removed
  MojoShader is now statically linked directly into FNA3D
  SDL2_image has been replaced with FNA3D_Image, which is built into FNA3D
  Add experimental support for WebAssembly via Emscripten and mono-wasm
  Update to FAudio 20.09
* Mon May 18 2020 ecsos <ecsos@opensuse.org>
- Rebase faudio-older-sdl2.patch to fix build error in Leap.
* Wed May  6 2020 Martin Pluskal <mpluskal@suse.com>
- Update to version 20.05:
  * No changelog available
* Wed Mar 18 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 20.03. No changelog
- Update faudio-older-sdl2.patch.
* Sun Mar  3 2019 Jan Engelhardt <jengelh@inai.de>
- Avoid name repetition in summaries.
- Update RPM groups.
- Ensure directories are owned.
* Sat Mar  2 2019 Marcus Meissner <meissner@suse.com>
- initial import of the FAudio library used by Wine
- Verson 19.03
- We build only the lib/FAudio part of this package.
- faudio-older-sdl2.patch: build against a bit older SDL2 on Leap 42.3.
